@@ -17,12 +17,13 @@ https://www.themoviedb.org/documentation/api/status-codes
 """
 
 __title__ = 'tmdbsimple'
-__version__ = '2.6.6'
+__version__ = '2.8.0'
 __author__ = 'Celia Oakley'
 __copyright__ = 'Copyright (c) 2013-2020 Celia Oakley'
 __license__ = 'GPLv3'
 
 import os
+import requests
 
 from .account import Account, Authentication, GuestSessions, Lists
 from .base import APIKeyError
@@ -51,3 +52,4 @@ __all__ = ['Account', 'Authentication', 'GuestSessions', 'Lists',
 
 API_KEY = os.environ.get('TMDB_API_KEY', None)
 API_VERSION = '3'
+REQUESTS_SESSION = None
